@@ -28,14 +28,13 @@
 
 #include <Akonadi/Calendar/ETMCalendar>
 #include <CalendarSupport/CategoryConfig>
-#include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/CategoryHierarchyReader>
 #include <LibkdepimAkonadi/TagSelectionCombo>
 
 #include <Libkdepim/KCheckComboBox>
 #include <LibkdepimAkonadi/TagWidgets>
 
-#include <KCalCore/CalFilter>
+#include <KCalendarCore/CalFilter>
 
 #include <KComboBox>
 #include <KDateComboBox>
@@ -57,16 +56,12 @@ TodoCompleteDelegate::~TodoCompleteDelegate()
 {
 }
 
-void TodoCompleteDelegate::paint(QPainter *painter,
-                                 const QStyleOptionViewItem &option,
-                                 const QModelIndex &index) const
+void TodoCompleteDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    QStyle *style;
-
     QStyleOptionViewItem opt = option;
     initStyleOption(&opt, index);
 
-    style = opt.widget ? opt.widget->style() : QApplication::style();
+    QStyle *style = opt.widget ? opt.widget->style() : QApplication::style();
     style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter);
 
     if (index.data(Qt::EditRole).toInt() > 0) {
@@ -89,8 +84,7 @@ void TodoCompleteDelegate::paint(QPainter *painter,
     }
 }
 
-QSize TodoCompleteDelegate::sizeHint(const QStyleOptionViewItem &option,
-                                     const QModelIndex &index) const
+QSize TodoCompleteDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QStyleOptionViewItem opt = option;
     initStyleOption(&opt, index);
@@ -106,8 +100,7 @@ QSize TodoCompleteDelegate::sizeHint(const QStyleOptionViewItem &option,
 }
 
 void TodoCompleteDelegate::initStyleOptionProgressBar(
-    QStyleOptionProgressBar *option,
-    const QModelIndex &index) const
+    QStyleOptionProgressBar *option, const QModelIndex &index) const
 {
     option->rect.adjust(0, 1, 0, -1);
     option->maximum = 100;
@@ -118,9 +111,7 @@ void TodoCompleteDelegate::initStyleOptionProgressBar(
     option->textVisible = true;
 }
 
-QWidget *TodoCompleteDelegate::createEditor(QWidget *parent,
-        const QStyleOptionViewItem &option,
-        const QModelIndex &index) const
+QWidget *TodoCompleteDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(option);
     Q_UNUSED(index);
@@ -133,26 +124,21 @@ QWidget *TodoCompleteDelegate::createEditor(QWidget *parent,
     return slider;
 }
 
-void TodoCompleteDelegate::setEditorData(QWidget *editor,
-        const QModelIndex &index) const
+void TodoCompleteDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
     QSlider *slider = static_cast<QSlider *>(editor);
 
     slider->setValue(index.data(Qt::EditRole).toInt());
 }
 
-void TodoCompleteDelegate::setModelData(QWidget *editor,
-                                        QAbstractItemModel *model,
-                                        const QModelIndex &index) const
+void TodoCompleteDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
     QSlider *slider = static_cast<QSlider *>(editor);
 
     model->setData(index, slider->value());
 }
 
-void TodoCompleteDelegate::updateEditorGeometry(QWidget *editor,
-        const QStyleOptionViewItem &option,
-        const QModelIndex &index) const
+void TodoCompleteDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(index);
 
@@ -188,9 +174,7 @@ TodoPriorityDelegate::~TodoPriorityDelegate()
 {
 }
 
-QWidget *TodoPriorityDelegate::createEditor(QWidget *parent,
-        const QStyleOptionViewItem &option,
-        const QModelIndex &index) const
+QWidget *TodoPriorityDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(option);
     Q_UNUSED(index);
@@ -211,26 +195,21 @@ QWidget *TodoPriorityDelegate::createEditor(QWidget *parent,
     return combo;
 }
 
-void TodoPriorityDelegate::setEditorData(QWidget *editor,
-        const QModelIndex &index) const
+void TodoPriorityDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
     KComboBox *combo = static_cast<KComboBox *>(editor);
 
     combo->setCurrentIndex(index.data(Qt::EditRole).toInt());
 }
 
-void TodoPriorityDelegate::setModelData(QWidget *editor,
-                                        QAbstractItemModel *model,
-                                        const QModelIndex &index) const
+void TodoPriorityDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
     KComboBox *combo = static_cast<KComboBox *>(editor);
 
     model->setData(index, combo->currentIndex());
 }
 
-void TodoPriorityDelegate::updateEditorGeometry(QWidget *editor,
-        const QStyleOptionViewItem &option,
-        const QModelIndex &index) const
+void TodoPriorityDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(index);
 
@@ -249,9 +228,7 @@ TodoDueDateDelegate::~TodoDueDateDelegate()
 {
 }
 
-QWidget *TodoDueDateDelegate::createEditor(QWidget *parent,
-        const QStyleOptionViewItem &option,
-        const QModelIndex &index) const
+QWidget *TodoDueDateDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(option);
     Q_UNUSED(index);
@@ -261,26 +238,21 @@ QWidget *TodoDueDateDelegate::createEditor(QWidget *parent,
     return dateEdit;
 }
 
-void TodoDueDateDelegate::setEditorData(QWidget *editor,
-                                        const QModelIndex &index) const
+void TodoDueDateDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
     KDateComboBox *dateEdit = static_cast<KDateComboBox *>(editor);
 
     dateEdit->setDate(index.data(Qt::EditRole).toDate());
 }
 
-void TodoDueDateDelegate::setModelData(QWidget *editor,
-                                       QAbstractItemModel *model,
-                                       const QModelIndex &index) const
+void TodoDueDateDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
     KDateComboBox *dateEdit = static_cast<KDateComboBox *>(editor);
 
     model->setData(index, dateEdit->date());
 }
 
-void TodoDueDateDelegate::updateEditorGeometry(QWidget *editor,
-        const QStyleOptionViewItem &option,
-        const QModelIndex &index) const
+void TodoDueDateDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(index);
     editor->setGeometry(QStyle::alignedRect(QApplication::layoutDirection(), Qt::AlignCenter,
@@ -291,7 +263,8 @@ void TodoDueDateDelegate::updateEditorGeometry(QWidget *editor,
 // ---------------------------------------------------------------
 
 TodoCategoriesDelegate::TodoCategoriesDelegate(QObject *parent)
-    : QStyledItemDelegate(parent), mCalendar(nullptr)
+    : QStyledItemDelegate(parent)
+    , mCalendar(nullptr)
 {
 }
 
@@ -299,9 +272,7 @@ TodoCategoriesDelegate::~TodoCategoriesDelegate()
 {
 }
 
-QWidget *TodoCategoriesDelegate::createEditor(QWidget *parent,
-        const QStyleOptionViewItem &option,
-        const QModelIndex &index) const
+QWidget *TodoCategoriesDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(option);
     Q_UNUSED(index);
@@ -309,26 +280,21 @@ QWidget *TodoCategoriesDelegate::createEditor(QWidget *parent,
     return new KPIM::TagSelectionCombo(parent);
 }
 
-void TodoCategoriesDelegate::setEditorData(QWidget *editor,
-        const QModelIndex &index) const
+void TodoCategoriesDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
     KPIM::KCheckComboBox *combo = static_cast<KPIM::KCheckComboBox *>(editor);
 
     combo->setCheckedItems(index.data(Qt::EditRole).toStringList(), Qt::UserRole);
 }
 
-void TodoCategoriesDelegate::setModelData(QWidget *editor,
-        QAbstractItemModel *model,
-        const QModelIndex &index) const
+void TodoCategoriesDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
     KPIM::KCheckComboBox *combo = static_cast<KPIM::KCheckComboBox *>(editor);
 
     model->setData(index, combo->checkedItems(Qt::UserRole));
 }
 
-void TodoCategoriesDelegate::updateEditorGeometry(QWidget *editor,
-        const QStyleOptionViewItem &option,
-        const QModelIndex &index) const
+void TodoCategoriesDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(index);
 
@@ -353,9 +319,7 @@ TodoRichTextDelegate::~TodoRichTextDelegate()
 {
 }
 
-void TodoRichTextDelegate::paint(QPainter *painter,
-                                 const QStyleOptionViewItem &option,
-                                 const QModelIndex &index) const
+void TodoRichTextDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     if (index.data(TodoModel::IsRichTextRole).toBool()) {
         QStyleOptionViewItem opt = option;
@@ -372,8 +336,8 @@ void TodoRichTextDelegate::paint(QPainter *painter,
         style->drawControl(QStyle::CE_ItemViewItem, &opt, painter, widget);
 
         // draw the text (rich text)
-        QPalette::ColorGroup cg = opt.state & QStyle::State_Enabled ?
-                                  QPalette::Normal : QPalette::Disabled;
+        QPalette::ColorGroup cg = (opt.state & QStyle::State_Enabled)
+                                  ? QPalette::Normal : QPalette::Disabled;
         if (cg == QPalette::Normal && !(opt.state & QStyle::State_Active)) {
             cg = QPalette::Inactive;
         }
@@ -410,8 +374,7 @@ void TodoRichTextDelegate::paint(QPainter *painter,
     }
 }
 
-QSize TodoRichTextDelegate::sizeHint(const QStyleOptionViewItem &option,
-                                     const QModelIndex &index) const
+QSize TodoRichTextDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QSize ret = QStyledItemDelegate::sizeHint(option, index);
     if (index.data(TodoModel::IsRichTextRole).toBool()) {
@@ -425,7 +388,7 @@ QSize TodoRichTextDelegate::sizeHint(const QStyleOptionViewItem &option,
     }
 
     // This row might not have a checkbox, so give it more height so it appears the same size as other rows.
-    const int checkboxHeight = QApplication::style()->sizeFromContents(QStyle::CT_CheckBox, &option, QSize()).height();
+    const int checkboxHeight = QApplication::style()->sizeFromContents(QStyle::CT_CheckBox, &option,
+                                                                       QSize()).height();
     return QSize(ret.width(), qMax(ret.height(), checkboxHeight));
 }
-
